---
name: User Story Template
about: standard user story issue template
title: User Story issue
labels: ''
assignees: ''

---

### Description
As a [developer/user/owner], I want [a feature/fix/change].

[description and details]

### Definition of Done
[description of finished task]

### Tasks/Items:
- [ ] First item
- [ ] Second item
- [ ] ...
- [ ] ...
- [ ] ...
